@@ -1,7 +1,7 @@
 package Complete::TZ;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-17'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -42,12 +42,12 @@ _
     },
 };
 sub complete_tz {
-    require Complete::Util;
+    require Complete::File;
 
     my %args  = @_;
     my $word  = $args{word} // "";
 
-    my $res = hashify_answer(Complete::Util::complete_file(
+    my $res = hashify_answer(Complete::File::complete_file(
         starting_path => '/usr/share/zoneinfo',
         handle_tilde => 0,
         allow_dot => 0,
@@ -77,7 +77,7 @@ Complete::TZ - Timezone-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.04 of Complete::TZ (from Perl distribution Complete-TZ), released on 2015-09-09.
+This document describes version 0.05 of Complete::TZ (from Perl distribution Complete-TZ), released on 2015-09-17.
 
 =head1 DESCRIPTION
 
